@@ -9,6 +9,7 @@ from shell import ShellCommand
 from startproject import StartProjectCommand
 from syncdb import SyncDbCommand
 from migratedb import MigrateDbCommand
+from browser import BrowserCommand
 
 class CommandsDict(dict):
 
@@ -26,6 +27,7 @@ d = { RunCommand.name : RunCommand,
       ShellCommand.name : ShellCommand,
       StartProjectCommand.name : StartProjectCommand,
       SyncDbCommand.name : SyncDbCommand,
+      BrowserCommand.name : BrowserCommand,
       MigrateDbCommand.name : MigrateDbCommand }
 
 commands.update(d)
