@@ -13,11 +13,8 @@ class RunCommand(ProjectCommand):
     name = "run"
 
     def execute(self):
-        
-        if "syncdb" not in self.kwargs or not self.kwargs["syncdb"]:
-            self.syncdb = SyncDbCommand(args=self.args, settings=self.settings, **self.kwargs)
-            self.syncdb.checked_execute()
-        else :
-            self.syncdb = self.kwargs["syncdb"]
+
+        self.syncdb = SyncDbCommand(args=self.args, settings=self.settings, **self.kwargs)
+        self.syncdb.checked_execute()
 
         self.project_type.run(self)
